@@ -447,7 +447,11 @@ class DynamoDBModel(object):
                 if e.error_code != "ConditionalCheckFailedException":
                     # Unhandled exception
                     raise
-                # The max key has changed (concurrent write): retry.
+                log.debug(
+                    "table=%s, max hash key has changed. Retrying (%s).",
+                    item.table, tries)
+        else:
+            raise MaxRetriesExceededError()
 
     def save(self, allow_overwrite=True, expected_values=None):
         """Save the object to the database.
